@@ -49,6 +49,7 @@ from PyQt5.QtWidgets import QMenu
 from PyQt5.QtWidgets import QMessageBox
 from PyQt5.QtWidgets import QPushButton
 from PyQt5.QtWidgets import QRadioButton
+from PyQt5.QtWidgets import QScrollArea
 from PyQt5.QtWidgets import QSizePolicy
 from PyQt5.QtWidgets import QTextEdit
 from PyQt5.QtWidgets import QToolBar
@@ -421,7 +422,7 @@ class DynamicButton(QWidget):
         self.setLayout(layout)
 
         label_icon = IconLabel(icon_path=self.icon_path, size=size)
-        label_text = QLabel(label)
+        label_text = QLabel(self.function_display_name)
 
         layout.addWidget(label_icon)
         layout.addSpacing(self.HorizontalSpacing)
@@ -453,6 +454,17 @@ class DynamicButton(QWidget):
         """Returns the name of the module where the function resides."""
         return self._function.__ui_module__
 
+    @property
+    def module_display_name(self) -> str:
+        try:
+            return sys.modules[self._function.__ui_module__].UI_MODULE_DISPLAY_NAME
+        except (AttributeError, KeyError):
+            return self.module_name.rsplit(".", 1)[-1]
+
+    @property
+    def function_display_name(self) -> str:
+        return self._function.__ui_display_name__ or self.label or self._function.__name__
+
     @property
     def label(self) -> str:
         return self._label
@@ -593,8 +605,9 @@ class ArgumentsPanel(QGroupBox):
         elif isinstance(arg.annotation, TypeObject):
             return field.get_value()
         else:
-            value = field.displayText() or field.placeholderText()
 
+            if not (value := field.displayText() or field.placeholderText()):
+                return None
             try:
                 if arg.annotation is tuple or arg.annotation is list:
                     return ast.literal_eval(value) if value else arg.annotation()
@@ -602,11 +615,15 @@ class ArgumentsPanel(QGroupBox):
             except (ValueError, TypeError, SyntaxError):
                 return value
 
-
-class FunctionButtonsPanel(QWidget):
+class FunctionButtonsPanel(QScrollArea):
     def __init__(self):
         super().__init__()
 
+        self.setWidgetResizable(True)
+        self.setMinimumSize(600, 300)
+
+        widget = QWidget()
+
         self.n_cols = 4  # This must be a setting or configuration option
 
         # The modules are arranged in a vertical layout and each of the functions in that module is arranged in a
@@ -616,16 +633,19 @@ class FunctionButtonsPanel(QWidget):
         self.buttons: Dict[str, int] = {}
         self.module_layout = QVBoxLayout()
 
-        self.setLayout(self.module_layout)
+        widget.setLayout(self.module_layout)
+
+        self.setWidget(widget)
 
     def add_button(self, button: DynamicButton):
         module_name = button.module_name
         if module_name not in self.modules:
+            display_name = button.module_display_name
             grid = QGridLayout()
             # Make sure all columns have equal width
             for idx in range(self.n_cols):
                 grid.setColumnStretch(idx, 1)
-            gbox = QGroupBox(module_name.rsplit(".", 1)[-1])
+            gbox = QGroupBox(display_name)
             gbox.setLayout(grid)
             gbox.setStyleSheet(textwrap.dedent("""
                 QGroupBox
@@ -696,7 +716,7 @@ class View(QMainWindow):
         # and set the policy such that it can still expand from this minimum size. This will be used
         # when we use adjustSize after replacing the arguments panel.
 
-        self.app_frame.setMinimumSize(500, 0)  # TODO: should be a setting
+        self.app_frame.setMinimumSize(600, 0)  # TODO: should be a setting
         sp = self.app_frame.sizePolicy()
         sp.setHorizontalPolicy(QSizePolicy.MinimumExpanding)
         self.app_frame.setSizePolicy(sp)
